/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.jcr.taglib;

import java.io.IOException;

import javax.jcr.Node;
import javax.jcr.Session;

import javax.servlet.jsp.JspException;

import com.squeakysand.commons.lang.StringUtils;
import com.squeakysand.jcr.NodeUtils;
import com.squeakysand.jsp.tagext.annotations.JspTag;
import com.squeakysand.jsp.tagext.annotations.JspTagAttribute;

@JspTag
public class NodeTag extends JcrSessionAwareSimpleTagSupport {

    private String nodeVar;
    private String path;

    @Override
    public void doTag() throws JspException, IOException {
        Session session = determineSession();
        Node node = NodeUtils.getNodeByPath(path, session);
        if (node != null) {
            String attributeName = determineAttributeName();
            getJspContext().setAttribute(attributeName, node);
        }
    }

    public String getPath() {
        return path;
    }

    @JspTagAttribute(required = true)
    public void setPath(String path) {
        this.path = path;
    }

    private String determineAttributeName() {
        String result = null;
        if (StringUtils.isNullOrEmpty(nodeVar)) {
            result = AttributeNames.CURRENT_NODE;
        } else {
            result = nodeVar;
        }
        return result;
    }
}
