/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.jcr.taglib;

import java.io.IOException;

import javax.jcr.Node;
import javax.jcr.RepositoryException;

import javax.servlet.jsp.JspException;

import com.squeakysand.jcr.SimpleNode;
import com.squeakysand.jsp.tagext.annotations.JspTag;
import com.squeakysand.jsp.tagext.annotations.JspTagAttribute;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

@JspTag(name = "title")
public class NodeTitleTag extends JcrSessionAwareSimpleTagSupport {

    private static final Logger LOG = LoggerFactory.getLogger(NodeTitleTag.class);
    private Node node;
    private String var;

    @Override
    public void doTag() throws JspException, IOException {
        validateNotNullOrEmptyAttribute("var", var);
        LOG.trace("called");
        SimpleNode targetNode = determineTargetNode();
        if (targetNode != null) {
            String title = targetNode.getTitle();
            LOG.debug("node title is: " + title);
            if (var != null) {
                getJspContext().setAttribute(var, title);
            } else {
                try {
                    LOG.debug("writing path out: " + targetNode.getPath());
                    getJspContext().getOut().print(targetNode.getPath());
                } catch (RepositoryException e) {
                    throw new JspException(e);
                }
            }
        }
    }

    public Node getNode() {
        return node;
    }

    @JspTagAttribute(rtexprvalue = true)
    public void setNode(Node node) {
        this.node = node;
    }

    public void setVar(String var) {
        this.var = var;
    }

    private SimpleNode determineTargetNode() {
        SimpleNode result = null;
        Node targetNode = null;
        // first check if a node was passed via an attribute
        if (node != null) {
            LOG.debug("node was passed in via an attribute");
            targetNode = node;
        } else {
            // if no node was passed via an attribute, then see if there is a current node in the pageContext
            try {
                targetNode = (Node) getJspContext().findAttribute(AttributeNames.CURRENT_NODE);
                LOG.debug("node was found via current node attribute");
            } catch (ClassCastException e) {
                LOG.error(e.getMessage(), e);
            }

        }
        LOG.debug("target node was " + targetNode);
        if (targetNode != null) {
            if (targetNode instanceof SimpleNode) {
                result = (SimpleNode) targetNode;
            } else {
                result = new SimpleNode(targetNode);
            }
        }
        LOG.debug("result node was " + result);
        return result;
    }
}
